# onix

Actually a snek!

## Usage

```
$ onix
```

## Versioning

`onix` uses [Calendar Versioning](https://calver.org/). For the available versions, see the tags on the GitHub repository.

## License

This project is licensed under the Apache License, see the [LICENSE](https://github.com/vinayak-mehta/onix/blob/master/LICENSE) file for details.
